<?php namespace ProcessWire;
/*
 * Simple Sitemap Renderer for RepeaterFlex
 */
class SitemapRenderer extends RepeaterFlexRenderer {
	public static function getModuleInfo() { return [
		'title' => __('Sitemap Renderer', __FILE__), // Module Title
		'summary' => __('Renders RepeaterFlex as a Sitemap.', __FILE__), // Module Summary
		'version' => 80,
		];
	}

	protected $depth = 0;
	protected $isHuman = false;	// Output undecorated list instead of XML
	public function setHuman($bHuman) { $this->isHuman = $bHuman; }

	// Define prefix and postfix depending on requested output format
	public function renderPrefix()
		{
		$this->depth = 1;	// Reset depth
		return( $this->isHuman	? '<ul>'
								: "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<urlset xmlns=\"http://www.sitemaps.org/schemas/sitemap/0.9\">" );
		}
	public function renderSuffix()
		{
		return( $this->isHuman	? str_repeat('</ul>', $this->depth)
								: "\n</urlset>" );
		}

	public function getPageEntry(Page $pg, $depth) {
		if($pg->isHidden() || $pg->isUnpublished())
			return('');
	if($this->isHuman)
		{
		$prefix = '';
		$dDepth = $depth - $this->depth;
		if($dDepth > 0)	$prefix = str_repeat('<ul>', $dDepth);
		if($dDepth < 0)	$prefix = str_repeat('</ul>', -$dDepth);
		$this->depth = $depth;
		return($prefix."<li><a href='{$pg->httpUrl}'>{$pg->title}</a></li>");
		}
	
	return("
<url>
\t<loc>{$pg->httpUrl}</loc>
\t<lastmod>" . date("Y-m-d", $pg->modified) . "</lastmod>
</url>");
	}
}
